@@ -1,8 +1,8 @@
-#' Print methods for objects of class `spp_raw*`
+#' Print methods for objects of class `spp_raw*`.
 #'
-#' Print the outputs of a Species+ API call
+#' Print the outputs of a Species+ API call.
 #'
-#' @param x An object of class `spp_raw*`.
+#' @param x an object of class `spp_raw*`.
 #' @param ... ignored.
 #'
 #' @return The JSON result.
@@ -15,6 +15,7 @@ NULL
 #' @export
 print.spp_raw <- function(x, ...) {
     print(jsonlite::toJSON(unclass(x), pretty = TRUE, auto_unbox = TRUE))
+    invisible(NULL)
 }
 
 #' @rdname print.spp
@@ -22,9 +23,10 @@ print.spp_raw <- function(x, ...) {
 #' @export
 print.spp_raw_multi <- function(x, ...) {
     print.spp_raw(x)
-    cat("\n")
+    cat_line()
     rcites_print_taxon_id(x$taxon_ids)
-    cat("\n")
+    cat_line()
+    invisible(NULL)
 }
 
 #' @rdname print.spp
@@ -40,9 +42,10 @@ print.spp_cites_leg <- function(x, ...) {
     rcites_print_df_rm(x$cites_quotas, col_rm = c("notes", "url"))
 
     rcites_print_title("Cites suspensions ($cites_suspensions):")
-
     rcites_print_df_rm(x$cites_suspensions, col_rm = c("notes",
         paste0("start_notification.", c("name", "date", "url"))))
+
+    invisible(NULL)
 }
 
 #' @method print spp_cites_leg_multi
@@ -50,8 +53,9 @@ print.spp_cites_leg <- function(x, ...) {
 #' @export
 print.spp_cites_leg_multi <- function(x, ...) {
     rcites_print_taxon_id(x$cites_listings$taxon_id)
-    cat("\n")
+    cat_line()
     print.spp_cites_leg(x)
+    invisible(NULL)
 }
 
 
@@ -65,6 +69,7 @@ print.spp_distr <- function(x, ...) {
     rcites_print_title("References ($references):")
     x$references$reference <- rcites_print_shorten(x$references$reference)
     rcites_print_df_rm(x$references)
+    invisible(NULL)
 }
 
 #' @method print spp_distr_multi
@@ -72,8 +77,9 @@ print.spp_distr <- function(x, ...) {
 #' @export
 print.spp_distr_multi <- function(x, ...) {
     rcites_print_taxon_id(x$distributions$taxon_id)
-    cat("\n")
+    cat_line()
     print.spp_distr(x)
+    invisible(NULL)
 }
 
 
@@ -89,6 +95,7 @@ print.spp_eu_leg <- function(x, ...) {
     rcites_print_title("EU decisions ($eu_decisions):")
     npr <- c("notes", "eu_decision_type.description", "start_event.url")
     rcites_print_df_rm(x$eu_decisions, col_rm = npr)
+    invisible(NULL)
 }
 
 #' @method print spp_eu_leg_multi
@@ -96,8 +103,9 @@ print.spp_eu_leg <- function(x, ...) {
 #' @export
 print.spp_eu_leg_multi <- function(x, ...) {
     rcites_print_taxon_id(x$eu_listings$taxon_id)
-    cat("\n")
+    cat_line()
     print.spp_eu_leg(x)
+    invisible(NULL)
 }
 
 
@@ -110,6 +118,7 @@ print.spp_refs <- function(x, ...) {
     x$references$citation <- rcites_print_shorten(x$references$citation,
         40)
     rcites_print_df(x$references)
+    invisible(NULL)
 }
 
 #' @method print spp_refs_multi
@@ -117,8 +126,9 @@ print.spp_refs <- function(x, ...) {
 #' @export
 print.spp_refs_multi <- function(x, ...) {
     rcites_print_taxon_id(x$references$taxon_id)
-    cat("\n")
+    cat_line()
     print.spp_refs(x)
+    invisible(NULL)
 }
 
 
@@ -141,4 +151,5 @@ print.spp_taxon <- function(x, ...) {
 
     cat("\nInformation available:",
       paste(paste0("$", names(x)), collapse = ", "), "\n")
+    invisible(NULL)
 }
