@@ -1,4 +1,4 @@
-#' Get current CITES appendix listings and reservations.
+#' Get current CITES appendix listings and reservations
 #'
 #' Retrieve current CITES appendix listings and reservations, CITES quotas, and
 #' CITES suspensions for a given taxon concept.
@@ -18,6 +18,9 @@
 #' set directly in `Renviron`. Alternatively, [set_token()] can
 #' be used to set `SPECIESPLUS_TOKEN` for the current session.
 #' @param verbose a logical. Should extra information be reported on progress?
+#' @param pause a duration (in second) to suspend execution for (see
+#' [Sys.sleep()]). This was added cause the web API returns a 404 error too many
+#' requests in a short time interval.
 #' @param ... Further named parameters, see [httr::GET()].
 #'
 #' @return If `raw` is set to `TRUE` then an object of class `spp_raw` (or
@@ -30,7 +33,7 @@
 #'  3. `cites_suspensions`: lists CITES suspensions.
 #'
 #' @references
-#' \url{https://api.speciesplus.net/documentation/v1/cites_legislation/index.html}
+#' <https://api.speciesplus.net/documentation/v1/cites_legislation/index.html>
 #'
 #' @export
 #'
@@ -44,11 +47,11 @@
 #' }
 
 spp_cites_legislation <- function(taxon_id, scope = "current", language = "en",
-    raw = FALSE, token = NULL, verbose = TRUE, ...) {
+    raw = FALSE, token = NULL, verbose = TRUE, pause = 1, ...) {
     if (length(taxon_id) > 1) {
         out <- lapply(taxon_id, spp_cites_legislation, scope = scope,
             language = language, raw = raw, token = token, verbose = verbose,
-            ...)
+            pause = pause, ...)
         out <- rcites_combine_lists(out, taxon_id, raw)
     } else {
         # token check
@@ -68,7 +71,7 @@ spp_cites_legislation <- function(taxon_id, scope = "current", language = "en",
             ## create url
             q_url <- rcites_url("taxon_concepts/", taxon_id,
               "/cites_legislation.json", query_string)
-            ## get_res
+            ## get results
             tmp <- rcites_res(q_url, token, ...)
             ## outputs
             if (raw) {
@@ -88,5 +91,6 @@ spp_cites_legislation <- function(taxon_id, scope = "current", language = "en",
         if (verbose)
             rcites_cat_done()
     }
+    Sys.sleep(pause)
     out
 }
