@@ -11,19 +11,22 @@
 #' set directly in `Renviron`. Alternatively, [set_token()] can be used to set
 #' `SPECIESPLUS_TOKEN` for the current session.
 #' @param verbose a logical. Should extra information be reported on progress?
+#' @param pause a duration (in second) to suspend execution for (see
+#' [Sys.sleep()]). This was added cause the web API returns a 404 error too many
+#' requests in a short time interval.
 #' @param ... Further named parameters, see [httr::GET()].
 #'
 #' @return If `raw` is set to `TRUE` then an object of class `spp_raw` (or
-#' `spp_raw_multi` if `length(taxon_id)>1`) is returned which is essentially
+#' `spp_raw_multi` if `length(taxon_id) > 1`) is returned which is essentially
 #' a list of lists (see option `as = 'parsed'` in [httr::content()]).
 #' Otherwise, an object of class `spp_refs` (or `spp_refs_multi` if
-#' `length(taxon_id)>1`) is returned which is a list of one
+#' `length(taxon_id) > 1`) is returned which is a list of one
 #' data frame:
 #' * `references` that includes the identifier of the reference and the
 #' corresponding citation.
 #'
 #' @references
-#' \url{https://api.speciesplus.net/documentation/v1/references/index.html}
+#' <https://api.speciesplus.net/documentation/v1/references/index.html>
 #'
 #' @export
 #'
@@ -36,11 +39,11 @@
 #' }
 
 spp_references <- function(taxon_id, raw = FALSE, token = NULL, verbose = TRUE,
-    ...) {
+    pause = 1, ...) {
 
     if (length(taxon_id) > 1) {
         out <- lapply(taxon_id, spp_references, raw = raw, token = token,
-            verbose = verbose, ...)
+            verbose = verbose, pause = pause, ...)
         out <- rcites_combine_lists(out, taxon_id, raw)
     } else {
         # token check
@@ -69,5 +72,6 @@ spp_references <- function(taxon_id, raw = FALSE, token = NULL, verbose = TRUE,
                 rcites_cat_done()
         }
     }
+    Sys.sleep(pause)
     out
 }
