@@ -1,6 +1,5 @@
-#' Get taxon concepts for a search term.
+#' Get taxon concepts for a search term
 #'
-#' @description
 #' Retrieve the taxon concept of a specific taxon (scientific name).
 #'
 #' @param query_taxon a character string containing the query (e.g. species).
@@ -23,15 +22,18 @@
 #' @param raw a logical. Should raw data be returned?
 #' @param token a character string containing the authentification token, see
 #' \url{https://api.speciesplus.net/documentation}. Default is set to
-#' `NULL` and requires the environment variable `SPECIESPLUS_TOKEN` to be
-#' set directly in `Renviron`. Alternatively, `set_token()` can
-#' be used to set `SPECIESPLUS_TOKEN` for the current session.
+#' `NULL` and requires the environment variable `SPECIESPLUS_TOKEN` to be set
+#' directly in `Renviron`. Alternatively, `set_token()` can be used to set
+#' `SPECIESPLUS_TOKEN` for the current session.
 #' @param verbose a logical. Should extra information be reported on progress?
+#' @param pause a duration (in second) to suspend execution for (see
+#' [Sys.sleep()]). This was added cause the web API returns a 404 error too many
+#' requests in a short time interval.
 #' @param ... Further named parameters, see [httr::GET()].
 #'
 #' @return
-#' If `raw=TRUE`, then a object of class `spp_raw` is returned, which is
-#' a list of lists. If `raw=FALSE`, then an object of class `spp_taxon` is
+#' If `raw = TRUE`, then a object of class `spp_raw` is returned, which is
+#' a list of lists. If `raw = FALSE`, then an object of class `spp_taxon` is
 #' returned, it is a collection of seven data frames:
 #' 1. `all_id`: general information for all entries, including non-active taxon
 #' concepts,
@@ -44,7 +46,7 @@
 #' (missing if `taxonomy == 'CMS'`).
 #'
 #' @references
-#' \url{https://api.speciesplus.net/documentation/v1/taxon_concepts/index.html}
+#' <https://api.speciesplus.net/documentation/v1/taxon_concepts/index.html>
 #'
 #' @export
 #'
@@ -61,7 +63,7 @@
 spp_taxonconcept <- function(query_taxon, taxonomy = "CITES",
     with_descendants = FALSE, language = NULL, updated_since = NULL,
     per_page = 500, pages = NULL, raw = FALSE, token = NULL, verbose = TRUE,
-    ...) {
+    pause = 1, ...) {
     # taxonomy check
     taxonomy <- match.arg(taxonomy, c("CITES", "CMS"))
     # token check
@@ -146,6 +148,6 @@ spp_taxonconcept <- function(query_taxon, taxonomy = "CITES",
             attr(out, "taxonomy") <- taxonomy
         }
     }
-    #
+    Sys.sleep(pause)
     out
 }
