@@ -34,9 +34,7 @@ test_that("Language", {
 })
 
 
-ut_pause(2)
 res5 <- spp_distributions(taxon_id = c(tx_id, tx_id2), verbose = FALSE)
-ut_pause()
 res6 <- spp_distributions(taxon_id = c(tx_id, tx_id2), raw = TRUE,
   verbose = FALSE)
 test_that("distr_multi outputs", {
@@ -51,3 +49,9 @@ test_that("distr_multi outputs", {
   expect_identical(res6$taxon_id, c(tx_id, tx_id2))
 })
 ut_pause()
+
+# taxon with only one distribution
+res7 <- spp_distributions("10000", verbose = FALSE)
+test_that("only one distribution", {
+  expect_equal(dim(res7$distribution)[1], 1)
+})
\ No newline at end of file
